==> whp-2025.07.38.tar.gz: whp-release-2025.07.38/web-files/filemanager/_files/config/config.php <==
<?php 

// CONFIG / https://www.files.gallery/docs/config/
// Uncomment the parameters you want to edit.
return array (
  'root' => HOME_DIR,
  //'start_path' => false,
  //'username' => '',
  //'password' => '',
  //'load_images' => true,
  'load_files_proxy_php' => true,
  //'load_images_max_filesize' => 1000000,
  //'image_resize_enabled' => true,
  //'image_resize_cache' => true,
  //'image_resize_dimensions' => 320,
  //'image_resize_dimensions_retina' => 480,
  //'image_resize_dimensions_allowed' => '',
  //'image_resize_types' => 'jpeg, png, gif, webp, bmp, avif',
  //'image_resize_quality' => 85,
  //'image_resize_function' => 'imagecopyresampled',
  //'image_resize_sharpen' => true,
  //'image_resize_memory_limit' => 256,
  //'image_resize_max_pixels' => 60000000,
  //'image_resize_min_ratio' => 1.5,
  //'image_resize_cache_direct' => false,
  //'folder_preview_image' => true,
  //'folder_preview_default' => '_filespreview.jpg',
  //'menu_enabled' => true,
  //'menu_show' => true,
  //'menu_max_depth' => 5,
  //'menu_sort' => 'name_asc',
  //'menu_cache_validate' => true,
  //'menu_load_all' => false,
  //'menu_recursive_symlinks' => true,
  'layout' => 'list',
  //'sort' => 'name_asc',
  //'sort_dirs_first' => true,
  //'sort_function' => 'locale',
  //'cache' => true,
  //'cache_key' => 0,
  //'storage_path' => '_files',
  //'files_exclude' => '',
  //'dirs_exclude' => '',
  //'allow_symlinks' => true,
  //'title' => '%name% [%count%]',
  //'history' => true,
  //'transitions' => true,
  //'click' => 'popup',
  //'click_window' => '',
  //'click_window_popup' => true,
  //'code_max_load' => 100000,
  //'topbar_sticky' => 'scroll',
  //'get_mime_type' => false,
  //'context_menu' => true,
  //'prevent_right_click' => false,
  'license_key' => 'F1-TA41-4051-426A-F4JN-62J5-19CW',
  //'filter_live' => true,
  //'filter_props' => 'name, filetype, mime, features, title',
  //'download_dir' => 'browser',
  //'download_dir_cache' => 'dir',
  //'assets' => '',
  'allow_upload' => true,
  'allow_delete' => true,
  'allow_rename' => true,
  'allow_new_folder' => true,
  'allow_new_file' => true,
  'allow_duplicate' => true,
  'allow_text_edit' => true,
  'allow_zip' => true,
  'allow_unzip' => true,
  'allow_move' => true,
  'allow_copy' => true,
  //'allow_download' => true,
  'allow_mass_download' => true,
  //'allow_mass_copy_links' => false,
  //'allow_check_updates' => false,
  //'allow_tests' => true,
  //'allow_tasks' => false,
  //'demo_mode' => false,
  //'upload_allowed_file_types' => '',
  //'upload_max_filesize' => 0,
  //'upload_exists' => 'increment',
  //'popup_video' => true,
  //'video_thumbs' => true,
  //'video_ffmpeg_path' => 'ffmpeg',
  //'lang_default' => 'en',
  //'lang_auto' => true,
);

==> whp-2025.09.6.tar.gz: whp-release-2025.09.6/web-files/filemanager/_files/config/config.php <==
<?php 

// CONFIG / https://www.files.gallery/docs/config/
// Uncomment the parameters you want to edit.
return array (
  // Use HOME_DIR if defined and not empty, otherwise use a safe fallback that will show an error
  // This prevents users from accidentally seeing the root filesystem
  'root' => (defined('HOME_DIR') && !empty(HOME_DIR)) ? HOME_DIR : '/home/nonexistent_user',
  //'start_path' => false,
  //'username' => '',
  //'password' => '',
  //'load_images' => true,
  'load_files_proxy_php' => true,
  //'load_images_max_filesize' => 1000000,
  //'image_resize_enabled' => true,
  //'image_resize_cache' => true,
  //'image_resize_dimensions' => 320,
  //'image_resize_dimensions_retina' => 480,
  //'image_resize_dimensions_allowed' => '',
  //'image_resize_types' => 'jpeg, png, gif, webp, bmp, avif',
  //'image_resize_quality' => 85,
  //'image_resize_function' => 'imagecopyresampled',
  //'image_resize_sharpen' => true,
  //'image_resize_memory_limit' => 256,
  //'image_resize_max_pixels' => 60000000,
  //'image_resize_min_ratio' => 1.5,
  //'image_resize_cache_direct' => false,
  //'folder_preview_image' => true,
  //'folder_preview_default' => '_filespreview.jpg',
  //'menu_enabled' => true,
  //'menu_show' => true,
  //'menu_max_depth' => 5,
  //'menu_sort' => 'name_asc',
  //'menu_cache_validate' => true,
  //'menu_load_all' => false,
  //'menu_recursive_symlinks' => true,
  'layout' => 'list',
  //'sort' => 'name_asc',
  //'sort_dirs_first' => true,
  //'sort_function' => 'locale',
  //'cache' => true,
  //'cache_key' => 0,
  //'storage_path' => '_files',
  //'files_exclude' => '',
  //'dirs_exclude' => '',
  //'allow_symlinks' => true,
  //'title' => '%name% [%count%]',
  //'history' => true,
  //'transitions' => true,
  //'click' => 'popup',
  //'click_window' => '',
  //'click_window_popup' => true,
  //'code_max_load' => 100000,
  //'topbar_sticky' => 'scroll',
  //'get_mime_type' => false,
  //'context_menu' => true,
  //'prevent_right_click' => false,
  'license_key' => 'F1-TA41-4051-426A-F4JN-62J5-19CW',
  //'filter_live' => true,
  //'filter_props' => 'name, filetype, mime, features, title',
  //'download_dir' => 'browser',
  //'download_dir_cache' => 'dir',
  //'assets' => '',
  'allow_upload' => true,
  'allow_delete' => true,
  'allow_rename' => true,
  'allow_new_folder' => true,
  'allow_new_file' => true,
  'allow_duplicate' => true,
  'allow_text_edit' => true,
  'allow_zip' => true,
  'allow_unzip' => true,
  'allow_move' => true,
  'allow_copy' => true,
  //'allow_download' => true,
  'allow_mass_download' => true,
  //'allow_mass_copy_links' => false,
  //'allow_check_updates' => false,
  //'allow_tests' => true,
  //'allow_tasks' => false,
  //'demo_mode' => false,
  //'upload_allowed_file_types' => '',
  //'upload_max_filesize' => 0,
  //'upload_exists' => 'increment',
  //'popup_video' => true,
  //'video_thumbs' => true,
  //'video_ffmpeg_path' => 'ffmpeg',
  //'lang_default' => 'en',
  //'lang_auto' => true,
);
